@@ -10,10 +10,12 @@ struct spvm_runtime_arg {
   const char* name;
   SPVM_RUNTIME_BASIC_TYPE* basic_type;
   SPVM_RUNTIME_METHOD* current_method;
+  SPVM_VALUE default_value;
   int32_t index;
   int32_t type_dimension;
   int32_t type_flag;
   int32_t stack_index;
+  int8_t is_optional;
 };
 
 #endif
