@@ -111,6 +111,7 @@ SPVM_API_RUNTIME* SPVM_API_RUNTIME_new_api() {
     SPVM_API_RUNTIME_get_spvm_stdout,
     SPVM_API_RUNTIME_get_spvm_stderr,
     SPVM_API_RUNTIME_get_env,
+    SPVM_API_RUNTIME_get_object_capacity_offset,
   };
   SPVM_API_RUNTIME* env_runtime = calloc(1, sizeof(env_runtime_init));
   memcpy(env_runtime, env_runtime_init, sizeof(env_runtime_init));
@@ -136,6 +137,11 @@ int32_t SPVM_API_RUNTIME_get_object_length_offset(SPVM_RUNTIME* runtime) {
   return offsetof(SPVM_OBJECT, length);
 }
 
+int32_t SPVM_API_RUNTIME_get_object_capacity_offset(SPVM_RUNTIME* runtime) {
+  
+  return offsetof(SPVM_OBJECT, capacity);
+}
+
 SPVM_RUNTIME_BASIC_TYPE* SPVM_API_RUNTIME_get_basic_type_by_id(SPVM_RUNTIME* runtime, int32_t basic_type_id) {
   
   if (basic_type_id < 0) {
