@@ -73,13 +73,13 @@ The elements in the range that is greater than or equal to L</"length"> field an
 
 =head2 capacity
 
-C<has capacity : ro int;>
+C<has capacity : virtual ro int;>
 
 The capacity. This is the length of the internally reserved elements to extend the length of the list.
 
 =head2 length
 
-C<has length : ro int;>
+C<has length : virtual ro int;>
 
 The length of the list.
 
@@ -120,6 +120,16 @@ Exceptions:
 
 $length must be greater than or equal to 0. Otherwise an exception is thrown.
 
+=head2 new_ref
+
+C<static method new_ref : L<ByteList|SPVM::> ($array : byte[]);>
+
+Creates a new L<ByteList|SPVM::> object, and set L</"array"> field to the array $array, and return the new object.
+
+Exceptions:
+
+The array $array must be defined. Otherwise an exception is thrown.
+
 =head1 Instance Methods
 
 =head2 get
@@ -258,9 +268,13 @@ Creates a new array with the length of the list and copies all elements of the l
 
 C<method get_array_unsafe : byte[] ();>
 
-Gets the internally array.
+Same as L</"get_array">, but this method is deprecated.
 
-This array is unsafe because it continues to point to the old array if the internal array is extended.
+=head2 get_array
+
+C<method get_array : byte[] ();>
+
+Returns the internal L</"array">.
 
 =head2 unshift
 
